import React, { useState, useEffect } from 'react';
import axios from '@/services/APIservices';
import { Loader2 } from 'lucide-react';

const FlashMessage = ({ message }) => (
  <div className="bg-red-100 border border-red-400 text-red-700 px-4 py-3 rounded relative mb-4">
    <span className="block sm:inline">{message}</span>
  </div>
);

const Form = ({ userId, editUserData, setEditUserData }) => {
  const BASE_URL = 'http://localhost:8000/user-img/user-images/';
  const DEFAULT_PHOTO = '/dashboard-profile.png';

  const getProfilePhotoUrl = (photoName) => {
    return !photoName || photoName === DEFAULT_PHOTO ? DEFAULT_PHOTO : BASE_URL + photoName;
  };

  const [imagePreview, setImagePreview] = useState(null);
  const [tempImageUrl, setTempImageUrl] = useState(null);
  const [isLoading, setIsLoading] = useState(false);
  const [error, setError] = useState(null);
  const [showFullPageLoader, setShowFullPageLoader] = useState(false);
  const [showFlashMessage, setShowFlashMessage] = useState(false);
  const [isDeletingPhoto, setIsDeletingPhoto] = useState(false);
  const [isConfirming, setIsConfirming] = useState(false);

  useEffect(() => {
    const currentImage = editUserData?.profile_photo ? getProfilePhotoUrl(editUserData.profile_photo) : DEFAULT_PHOTO;
    setImagePreview(currentImage);
  }, [editUserData?.profile_photo]);

  const handleInputChange = (e) => {
    const { name, value } = e.target;
    setEditUserData((prevData) => ({
      ...prevData,
      [name]: value.trim(),
    }));
  };

  const handleImageUpload = (e) => {
    // Check if there's an existing image from backend (not temp and not default)
    if (imagePreview && imagePreview !== DEFAULT_PHOTO && !tempImageUrl) {
      e.target.value = '';  // Clear the file input
      setShowFlashMessage(true);
      setTimeout(() => setShowFlashMessage(false), 3000);
      return;
    }

    const file = e.target.files[0];
    if (!file) return;

    // Validate file type and size
    const validTypes = ['image/jpeg', 'image/png', 'image/gif'];
    if (!validTypes.includes(file.type)) {
      setError('Please upload a valid image file (JPEG, PNG, or GIF)');
      return;
    }

    if (file.size > 5 * 1024 * 1024) {
      setError('Image size should be less than 5MB');
      return;
    }

    // Clear previous error if any
    setError(null);

    // Clean up previous temp URL
    if (tempImageUrl) {
      URL.revokeObjectURL(tempImageUrl);
    }

    const objectUrl = URL.createObjectURL(file);
    setTempImageUrl(objectUrl);
    setEditUserData((prevData) => ({
      ...prevData,
      profile_photo: file,
    }));
  };

  const handleDeleteClick = async (e) => {
    e.preventDefault();
    
    if (!isConfirming) {
      setIsConfirming(true);
      setTimeout(() => setIsConfirming(false), 3000);
      return;
    }

    try {
      setIsDeletingPhoto(true);
      setError(null);

      const response = await axios.delete(`/api/deleteUserImg/${userId}`);

      if (response.data?.success) {
        if (tempImageUrl) {
          URL.revokeObjectURL(tempImageUrl);
        }
        setTempImageUrl(null);
        setImagePreview(DEFAULT_PHOTO);
        setEditUserData((prevData) => ({
          ...prevData,
          profile_photo: DEFAULT_PHOTO,
        }));

        const userData = JSON.parse(localStorage.getItem('userData') || '{}');
        userData.profile_photo = DEFAULT_PHOTO;
        localStorage.setItem('userData', JSON.stringify(userData));
      } else {
        throw new Error(response.data?.message || 'Failed to delete photo');
      }
    } catch (err) {
      console.error('Delete photo error:', err);
      setError(err.response?.data?.message || 'Error deleting profile photo');
    } finally {
      setIsDeletingPhoto(false);
      setIsConfirming(false);
    }
  };

  const handleSubmit = async (e) => {
    e.preventDefault();
    setIsLoading(true);
    setError(null);

    try {
      const formData = new FormData();

      // Validate required fields
      if (!editUserData.name?.trim()) {
        throw new Error('Name is required');
      }
      if (!editUserData.email?.trim()) {
        throw new Error('Email is required');
      }

      if (editUserData.profile_photo instanceof File) {
        formData.append('profile_photo', editUserData.profile_photo);
      }

      formData.append('name', editUserData.name.trim());
      formData.append('email', editUserData.email.trim());
      formData.append('mobile_number', editUserData.mobile_number?.trim() || '');
      if (editUserData.password?.trim()) {
        formData.append('password', editUserData.password.trim());
      }

      const response = await axios.post(`/api/editUserData/${userId}`, formData, {
        headers: {
          'Content-Type': 'multipart/form-data',
        },
      });

      if (response.data?.message === 'User details updated successfully') {
        const userData = JSON.parse(localStorage.getItem('userData') || '{}');
        userData.profile_photo = response.data.user.profile_photo;
        localStorage.setItem('userData', JSON.stringify(userData));

        if (tempImageUrl) {
          URL.revokeObjectURL(tempImageUrl);
          setTempImageUrl(null);
        }
        
        setShowFullPageLoader(true);
        await new Promise((resolve) => setTimeout(resolve, 300));
        localStorage.clear();
        window.location.href = '/';
      }
    } catch (err) {
      setError(err.message || err.response?.data?.message || 'Error updating profile');
    } finally {
      setIsLoading(false);
    }
  };

  useEffect(() => {
    return () => {
      if (tempImageUrl) {
        URL.revokeObjectURL(tempImageUrl);
      }
    };
  }, [tempImageUrl]);

  return (
    <>
      {showFullPageLoader && (
        <div className="fixed inset-0 bg-white z-50 flex items-center justify-center">
          <div className="flex flex-col items-center gap-4">
            <Loader2 className="w-12 h-12 text-blue-500 animate-spin" />
            <p className="text-blue-500 font-medium text-lg">Updating details...</p>
          </div>
        </div>
      )}

      <div className="relative flex flex-col gap-6">
        {((isLoading && !showFullPageLoader) || isDeletingPhoto) && (
          <div className="absolute inset-0 bg-white/50 flex items-center justify-center z-40">
            <div className="flex flex-col items-center gap-2">
              <Loader2 className="w-8 h-8 text-blue-500 animate-spin" />
              <p className="text-blue-500 font-medium">
                {isDeletingPhoto ? 'Deleting photo...' : 'Details updating...'}
              </p>
            </div>
          </div>
        )}

        {showFlashMessage && (
          <FlashMessage message="Please delete the existing image first to upload a new one." />
        )}

        {error && (
          <div className="bg-red-100 border border-red-400 text-red-700 px-4 py-3 rounded">
            <span className="block sm:inline">{error}</span>
          </div>
        )}

        <div className="flex flex-wrap sm:flex-nowrap gap-6 items-center">
          <img
            src={tempImageUrl || imagePreview || DEFAULT_PHOTO}
            alt="Profile"
            className="w-24 h-24 rounded-full object-cover border-2 border-gray-200"
            onError={(e) => {
              e.target.src = DEFAULT_PHOTO;
              setImagePreview(DEFAULT_PHOTO);
            }}
          />
          <div className="relative">
            <input
              type="file"
              name="profile_photo"
              id="profile_photo"
              accept="image/jpeg,image/png,image/gif"
              className="absolute top-0 opacity-0 w-full h-full cursor-pointer"
              onChange={handleImageUpload}
              disabled={isLoading || showFullPageLoader || isDeletingPhoto}
            />
            <button
              type="button"
              disabled={isLoading || showFullPageLoader || isDeletingPhoto}
              className="bg-blue-500 hover:bg-blue-600 text-white py-2 px-4 rounded-lg font-semibold disabled:opacity-50 disabled:cursor-not-allowed"
            >
              Upload Photo
            </button>
          </div>
          {imagePreview !== DEFAULT_PHOTO && !tempImageUrl && (
            <button
              type="button"
              onClick={handleDeleteClick}
              disabled={isLoading || showFullPageLoader || isDeletingPhoto}
              className="bg-red-500 hover:bg-red-600 text-white py-2 px-4 rounded-lg font-semibold disabled:opacity-50 disabled:cursor-not-allowed"
            >
              {isConfirming ? 'Click Again to Confirm' : 'Delete'}
            </button>
          )}
        </div>

        <form className="flex flex-col gap-4" onSubmit={handleSubmit}>
          <div className="flex flex-col sm:flex-row gap-4">
            <div className="w-full">
              <input
                name="name"
                value={editUserData?.name || ''}
                placeholder="Enter Full Name"
                className="w-full px-4 py-2 border rounded-md focus:outline-none focus:ring-2 focus:ring-blue-500"
                onChange={handleInputChange}
                disabled={isLoading || showFullPageLoader || isDeletingPhoto}
                required
              />
            </div>
            <div className="w-full">
              <input
                name="email"
                type="email"
                value={editUserData?.email || ''}
                placeholder="Enter Email ID"
                className="w-full px-4 py-2 border rounded-md focus:outline-none focus:ring-2 focus:ring-blue-500"
                onChange={handleInputChange}
                disabled={isLoading || showFullPageLoader || isDeletingPhoto}
                required
              />
            </div>
          </div>

          <div className="flex flex-col sm:flex-row gap-4">
            <div className="w-full">
              <input
                type="tel"
                name="mobile_number"
                value={editUserData?.mobile_number || ''}
                placeholder="Enter Phone Number"
                className="w-full px-4 py-2 border rounded-md focus:outline-none focus:ring-2 focus:ring-blue-500"
                onChange={handleInputChange}
                disabled={isLoading || showFullPageLoader || isDeletingPhoto}
              />
            </div>
            <div className="w-full">
              <input
                name="password"
                type="password"
                placeholder="Update your new password"
                className="w-full px-4 py-2 border rounded-md focus:outline-none focus:ring-2 focus:ring-blue-500"
                onChange={handleInputChange}
                disabled={isLoading || showFullPageLoader || isDeletingPhoto}
              />
            </div>
          </div>

          <button
            type="submit"
            disabled={isLoading || showFullPageLoader || isDeletingPhoto}
            className="bg-blue-500 hover:bg-blue-600 text-white py-2 px-4 rounded-lg font-semibold disabled:opacity-50 disabled:cursor-not-allowed"
          >
            {isLoading ? 'Updating...' : 'Update Account'}
          </button>
        </form>
      </div>
    </>
  );
};

export default Form;